@@ -85,7 +85,7 @@ class FakePartnerForm(TrytonFactory):
             "birth_date": date(
                 int(self.birth_date_year),
                 int(self.birth_date_month),
-                int(self.birth_date_day)
+                int(self.birth_date_day),
             ),
             "vat_number": self.vat_number,
             "email": self.email,
